/** 
*   Docutain SDK React Native
*   Copyright (c) INFOSOFT Informations- und Dokumentationssysteme GmbH. All rights reserved.
*
*   Docutain SDK React Native is a commercial product and requires a license. 
*   Details found in the LICENSE file in the root directory of this source tree.
*/

import { NativeModules, Platform } from 'react-native';

import type {PageEditConfiguration, DocumentScannerConfiguration, AnalyzeConfiguration, PageSourceType} from './model';
import type {PDFPageFormat, LogLevel} from './model';
import { Int32 } from 'react-native/Libraries/Types/CodegenTypes';

export {PageEditConfiguration, DocumentScannerConfiguration, AnalyzeConfiguration, PDFPageFormat, LogLevel};

const LINKING_ERROR =
  `The package 'react-native-docutain-sdk' doesn't seem to be linked. Make sure: \n\n` +
  Platform.select({ ios: "- You have run 'pod install'\n", default: '' }) +
  '- You rebuilt the app after installing the package\n' +
  '- You are not using Expo Go\n';

export interface DocutainSDK {    
    initSDK(licenseKey: string): Promise<boolean> 
    scanDocument(options: DocumentScannerConfiguration): Promise<boolean>;
    loadFile(filePath: string): Promise<boolean>;
    getText(): Promise<string>;
    setAnalyzeConfiguration(config: AnalyzeConfiguration): Promise<boolean>;
    analyze(): Promise<string>;
    writePDF(filePath: string, overWrite: boolean, PDF_PageFormat: PDFPageFormat): Promise<string>;
    getLastError(): Promise<string>;
    setLogLevel(logLevel: LogLevel): Promise<boolean>;
    getTraceFile(): Promise<string>;
    deleteTempFiles(deleteTraceFileContent: boolean): Promise<boolean>;
    writeImage(pageNumber: Int32, filePath: string): Promise<string>;
    getImageBytes(pageNumber: Int32, pageSourceType: PageSourceType): Promise<string>;
}

const DocutainSDK: DocutainSDK = NativeModules.DocutainSdk
 ? NativeModules.DocutainSdk
 : new Proxy(
     {},
     {
       get() {
         throw new Error(LINKING_ERROR);
       },
     }
   );


export default DocutainSDK;
